@@ -640,7 +640,8 @@ class Straditizer(LabelSelection):
             ymax, xmax = right[
                 :, right.shape[1] - 1 - right.max(0)[::-1].argmax()]
         else:
-            xmax = len(cum_y) - 1 - (cum_y[::-1] > max_v).any(axis=0).argmax()
+            xmax = cum_y.shape[1] - 1 - (cum_y[:, ::-1] > max_v).any(
+                axis=0).argmax()
             ymax = len(cum_x) - 1 - (cum_x[::-1] > max_h).any(axis=1).argmax()
 
         left = np.vstack(np.where((cum_xr > max_h) & (cum_yr > max_v)))
@@ -1202,7 +1203,8 @@ class Straditizer(LabelSelection):
 
         def new_mark(pos):
             return [_new_mark(
-                [np.array(starts + full_df.loc[np.round(pos[-1] - ylim[0])]),
+                [np.array(starts +
+                          full_df.loc[np.round(pos[-1] - ylim[0])].fillna(0)),
                  np.round(pos[-1])])]
 
         def new_mark_and_range(key, row, row_indices):
@@ -1225,17 +1227,17 @@ class Straditizer(LabelSelection):
 
         reader = self.data_reader
         occ_val = reader.occurences_value
-        means = reader.all_column_bounds.mean(axis=1)
+        means = np.diff(reader.all_column_bounds, axis=1).ravel() / 2.
         if reader.full_df is None:
             reader.digitize()
         df = reader.sample_locs
         full_df = reader._full_df
         self.remove_marks()
         ax = self.ax
-        idx_v = self.indexes['y']
-        idx_h = self.column_indexes
         xlim = self.data_xlim
         ylim = self.data_ylim
+        idx_v = self.indexes['y'][slice(*map(int, ylim))]
+        idx_h = self.column_indexes
         starts = reader.all_column_starts + xlim[0]
         if not len(df):
             self.marks = marks = []
@@ -1312,7 +1314,7 @@ class Straditizer(LabelSelection):
                     else:
                         artists = []
                 if val == occ_val:
-                    val = bounds[col].mean()
+                    val = np.diff(bounds[col])[0] / 2.
                 marks.append(_new_mark([val, key], ax, artists))
             for mark, val in zip(marks, row):
                 mark._is_occurence = [val == occ_val]
