@@ -21,12 +21,14 @@ along with this program. If not, see <https://www.gnu.org/licenses/>.
 from __future__ import division
 import warnings
 import weakref
-import os
+import os.path as osp
 import six
 from functools import partial
 import re
 import numpy as np
+import pickle
 import pandas as pd
+import xarray as xr
 from straditize.widgets import StraditizerControlBase, get_icon
 from psyplot_gui.compat.qtcompat import (
     QPushButton, QLineEdit, QComboBox, QLabel, QDoubleValidator,
@@ -1421,21 +1423,40 @@ class DigitizingControl(StraditizerControlBase):
             we ask for a name"""
         if fname is None or not isinstance(fname, six.string_types):
             fname = QFileDialog.getOpenFileName(
-                self.straditizer_widgets, 'samples', os.getcwd(),
+                self.straditizer_widgets, 'samples',
+                self.straditizer_widgets.menu_actions._start_directory,
                 'CSV files (*.csv);;'
+                'Excel files (*.xls *.xlsx);;'
+                'Straditize projects (*.nc *.nc4 *.pkl);;'
                 'All files (*)'
                 )
             if with_qt5:  # the filter is passed as well
                 fname = fname[0]
         if not fname:
             return
-        df = pd.read_csv(fname)
-        samples = df.iloc[:, 0].values
+        base, ext = osp.splitext(fname)
+        if ext in ['.nc', '.nc4']:
+            with xr.open_dataset(fname) as ds:
+                df = self.straditizer.from_dataset(ds, plot=False).final_df
+        elif ext == '.pkl':
+            with open(fname, 'rb') as f:
+                df = pickle.load(f).final_df
+        elif ext in ['.xls', '.xlsx']:
+            df = pd.read_excel(fname, index_col=0)
+        else:
+            df = pd.read_csv(fname, index_col=0)
+        samples = df.index.values
         try:
             samples = self.straditizer.data2px_y(samples)
         except ValueError:
             pass
-        self.straditizer.data_reader.add_samples(samples.astype(int))
+        # HACK: truncate to the available data region
+        # This could be better solved through a dialog with the user...
+        maxy = len(self.reader._full_df) - 1
+        samples[samples < 0] = 0
+        samples[samples > maxy] = maxy
+        self.straditizer.data_reader.add_samples(
+            np.unique(samples.astype(int)))
         self.straditizer_widgets.refresh()
 
     def edit_samples(self):
@@ -1570,8 +1591,8 @@ class DigitizingControl(StraditizerControlBase):
         tb.data_obj = 'Reader'
         self.reader.recognize_xaxes(fraction=fraction, min_lw=min_lw,
                                     max_lw=max_lw)
-        self.straditizer_widgets.apply_button.clicked.connect(
-            self.reader.set_hline_locs_from_selection)
+        self.apply_button.clicked.connect(
+            lambda: self.reader.set_hline_locs_from_selection())
         tb.start_selection(rgba=tb.data_obj.image_array())
         tb.remove_select_action.setChecked(True)
         if not tb.wand_action.isChecked():
@@ -1592,8 +1613,8 @@ class DigitizingControl(StraditizerControlBase):
         tb.data_obj = 'Reader'
         self.reader.recognize_hlines(fraction=fraction, min_lw=min_lw,
                                      max_lw=max_lw)
-        self.straditizer_widgets.apply_button.clicked.connect(
-            self.reader.set_hline_locs_from_selection)
+        self.apply_button.clicked.connect(
+            lambda: self.reader.set_hline_locs_from_selection())
         tb.start_selection(rgba=tb.data_obj.image_array())
         tb.remove_select_action.setChecked(True)
         if not tb.wand_action.isChecked():
@@ -1614,8 +1635,8 @@ class DigitizingControl(StraditizerControlBase):
         tb.data_obj = 'Reader'
         self.reader.recognize_yaxes(fraction=fraction, min_lw=min_lw,
                                     max_lw=max_lw)
-        self.straditizer_widgets.apply_button.clicked.connect(
-            self.reader.set_vline_locs_from_selection)
+        self.apply_button.clicked.connect(
+            lambda: self.reader.set_vline_locs_from_selection())
         tb.start_selection(rgba=tb.data_obj.image_array())
         tb.remove_select_action.setChecked(True)
         if not tb.wand_action.isChecked():
@@ -1636,8 +1657,8 @@ class DigitizingControl(StraditizerControlBase):
         tb.data_obj = 'Reader'
         self.reader.recognize_vlines(fraction=fraction, min_lw=min_lw,
                                      max_lw=max_lw)
-        self.straditizer_widgets.apply_button.clicked.connect(
-            self.reader.set_vline_locs_from_selection)
+        self.apply_button.clicked.connect(
+            lambda: self.reader.set_vline_locs_from_selection())
         tb.start_selection(rgba=tb.data_obj.image_array())
         tb.remove_select_action.setChecked(True)
         if not tb.wand_action.isChecked():
